#
# spec file for package opera
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global __provides_exclude_from ^%{_libdir}/opera/.*\\.so.*$
# libffmpeg.so*, libfreetype.so* and libGLESv2.so* are currently bundled.
%global __requires_exclude ^lib(ffmpeg|freetype|GLESv2)\\.so.*$
Name:           opera
Version:        49.0.2725.64
Release:        59.1
Summary:        Proprietary web browser
License:        SUSE-NonFree
Group:          Productivity/Networking/Web/Browsers
Url:            https://opera.com/
Source:         https://get.geo.opera.com/ftp/pub/%{name}/desktop/%{version}/linux/%{name}-stable_%{version}_amd64.rpm
Source2:        %{name}.appdata.xml
Source3:        %{name}.sh.in
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  xz
Recommends:     ffmpeg
Recommends:     flash-player-ppapi
# opera-gtk and opera-kde4 were last used in openSUSE 13.1.
Provides:       %{name}-gtk = %{version}
Obsoletes:      %{name}-gtk < %{version}
Provides:       %{name}-kde4 = %{version}
Obsoletes:      %{name}-kde4 < %{version}
ExclusiveArch:  x86_64

%description
Opera is a proprietary, fast, and user-friendly web browser.
It includes web developer tools, news aggregation, and the ability
to compress data via Opera Turbo on congested networks.

%prep
rpm2cpio %{SOURCE0} | cpio -i -d

cp -f %{SOURCE2} %{name}.appdata.xml

chmod -s .%{_libdir}/%{name}/%{name}_sandbox
cp -f .%{_libdir}/%{name}/resources/license.txt COPYING
sed -i 's/^\(TargetEnvironment\)/X-\1/' .%{_datadir}/applications/%{name}.desktop

sed \
  -e 's|__LIBDIR__|%{_libdir}|g' \
  -e 's|__SYSCONFDIR__|%{_sysconfdir}|g' \
  %{SOURCE3} > %{name}.sh
cat > %{name}.conf << EOF
# Default settings for opera. This file is sourced by /usr/bin/opera.

# Options to pass to opera.
OPERA_FLAGS=""
EOF

%build
# Nothing to build.

%install
mkdir -p %{buildroot}%{_libdir}/
cp -a .%{_libdir}/%{name} %{buildroot}%{_libdir}/%{name}
install -Dpm 0755 %{name}.sh %{buildroot}%{_bindir}/%{name}

install -Dpm 0644 .%{_datadir}/applications/%{name}.desktop \
  %{buildroot}%{_datadir}/applications/%{name}.desktop
cp -a .%{_datadir}/icons/ %{buildroot}%{_datadir}/

install -Dpm 0755 %{name}.sh %{buildroot}%{_bindir}/%{name}
install -Dpm 0644 %{name}.conf %{buildroot}%{_sysconfdir}/default/%{name}

# https://en.opensuse.org/openSUSE:AppStore
install -Dpm 0644 %{name}.appdata.xml \
  %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%fdupes %{buildroot}%{_libdir}/

%if 0%{?suse_version} <= 1320
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%doc COPYING
%config(noreplace) %{_sysconfdir}/default/%{name}
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/*
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Fri Dec 29 2017 sor.alexei@meowr.ru
- Update to version 49.0.2725.64:
  * VPN "Select virtual location" translations.
  * Fix Opera O49 not working with chromium-codecs-ffmpeg-extra
    version 63.
* Sun Dec 17 2017 sor.alexei@meowr.ru
- Update to version 49.0.2725.56:
  * Shift-clicking reload should force-reload the page but it also
    opens a tab.
  * Changes to opera:about translations.
  * Integrate translations for new virtual locations.
  * CreditCardSaveManagerTest failures in smoketests.
  * Add a Santa emoticon to Snaptool.
* Sat Nov 18 2017 sor.alexei@meowr.ru
- Update to version 49.0.2725.39:
  * Fix a crash at
    opera::StatsServiceImpl::StartNewLog(base::Callback).
* Wed Nov  8 2017 sor.alexei@meowr.ru
- Update to version 49.0.2725.34:
  * See https://blogs.opera.com/desktop/changelog-for-49/#b2725.34
* Fri Oct 27 2017 sor.alexei@meowr.ru
- Update to version 48.0.2685.52:
  * Allow Ctrl+C when capturing the screen to copy what’s marked.
  * Take a snapshot from the surface for PDF viewer snaps.
* Thu Oct 19 2017 sor.alexei@meowr.ru
- Update to version 48.0.2685.50:
  * See https://blogs.opera.com/desktop/changelog-for-48/#b2685.50
* Tue Sep 12 2017 sor.alexei@meowr.ru
- Exclude libGLESv2.so from RPM requirements (boo#1058188).
* Tue Aug 29 2017 luc14n0@linuxmail.org
- Update to version 47.0.2631.55:
  * Full changelog: https://blogs.opera.com/desktop/changelog-for-47/#b2631.55
* Thu Jul 27 2017 kieltux@gmail.com
- Update to version 46.0.2597.57:
  * Full changelog available at:
    https://blogs.opera.com/desktop/changelog-for-46/#b2597.57
* Thu Jul 13 2017 sor.alexei@meowr.ru
- Update to version 46.0.2597.46:
  * Fix white frame around a PDF file.
  * UTF encoding problems in installation_status.xml in China –
    results in uninstallation and AU errors.
* Fri Jun 30 2017 kieltux@gmail.com
- Update to version 46.0.2597.32:
  * Full changelog available at:
    https://blogs.opera.com/desktop/changelog-for-46/#b2597.32
* Fri Jun 23 2017 sor.alexei@meowr.ru
- Update to version 46.0.2597.26:
  * See https://blogs.opera.com/desktop/changelog-for-46/#b2597.26
- Switch to unpacking RPM.
- Recommend flash-player-ppapi instead of chromium-pepper-flash.
* Tue Jun 20 2017 kieltux@gmail.com
- Update to version 45.0.2552.898:
  * Full changelog available at:
    https://blogs.opera.com/desktop/changelog-for-45/#b2552.898
* Mon Jun  5 2017 kieltux@gmail.com
- Update to version 45.0.2552.888:
  * Full changelog available at:
    https://blogs.opera.com/desktop/changelog-for-45/#b2552.888
* Sat May 27 2017 kieltux@gmail.com
- Update to version 45.0.2552.881:
  * Full changelog available at:
    https://blogs.opera.com/desktop/changelog-for-45/#b2552.881
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 45.0.2552.635:
  * See https://opera.com/blogs/desktop/changelog-for-45
* Sat Apr 29 2017 kieltux@gmail.com
- Update to version 44.0.2510.1449:
  * Full changelog available at:
    https://www.opera.com/blogs/desktop/changelog-for-44/#b2510.1449
* Sun Apr 16 2017 kieltux@gmail.com
- Update to version 44.0.2510.1218:
  * Full changelog available at:
    https://www.opera.com/blogs/desktop/changelog-for-44/#b2510.1218
* Sun Apr  9 2017 kieltux@gmail.com
- Update to version 44.0.2510.1159:
  * Full changelog available at:
    https://www.opera.com/blogs/desktop/changelog-for-44/#b2510.1159
* Sat Mar  4 2017 kieltux@gmail.com
- Update to version 43.0.2442.1144:
  * Full changelog available at:
    https://www.opera.com/blogs/desktop/changelog-for-43/#b2442.1144
* Wed Feb 22 2017 danny.al-gaaf@bisect.de
- Update to version 43.0.2442.991
* Tue Feb  7 2017 sor.alexei@meowr.ru
- Update to version 43.0.2442.806:
  * See https://opera.com/blogs/desktop/changelog-for-43
* Sun Jan 29 2017 kieltux@gmail.com
- Update to version 42.0.2393.517:
  * Full changelog available at:
    https://www.opera.com/blogs/desktop/changelog-for-42/#b2393.517
* Sat Jan 21 2017 kieltux@gmail.com
- Update to version 42.0.2393.137
  * [Linux] Chinese websites are not readable on Ubuntu 16.04
  * Notification setting icon doesn’t open notification exceptions
    settings
  * Firewall prompt triggered on start with media-router flag
    enabled
  * H264 video does not work on Linux
  * Unsorted Bookmarks are not visible
  * Unreported installer error when trying to install x64ver in
    other location that already installed x32ver
  * Add installer architecture *stats*
  * Update 360 build with preinstalled extension
* Sun Dec 25 2016 kieltux@gmail.com
- Update to version 42.0.2393.94:
  * Fix a crash in KeyStorageKeyring::GetKey.
  * Fix a rash at opera::BookmarkMenuDelegate.
  * Port Chromium's fix for a
    content::TextInputClientObserver::GetFocusedPepperPlugin
    crash to desktop-stable-55-2393.
  * Update Chromium to version 55.0.2883.87.
* Tue Dec 13 2016 sor.alexei@meowr.ru
- Update to version 42.0.2393.85:
  * No changelog available.
* Sun Nov 27 2016 kieltux@gmail.com
- Update to 41.0.2353.69:
  * Moving elements in bookmarks bar crashes Opera
* Sat Nov 19 2016 mailaender@opensuse.org
- Add appdata.xml for https://software.opensuse.org/appstore
* Thu Nov 10 2016 kieltux@gmail.com
- Update to 41.0.2353.56:
  * Crash on refreshing of tooltip text when deleting a bookmarks
    bar bookmark in folder menu
  * Crash if host player closed right after opening detached
    video
  * Weird animation when opening a tab with middle-click when
    there’s tabs to the right of the active one already
  * Detached video is white for few seconds after detaching
  * On any page refresh, the video popout closes
  * Keyboard input breaks after right clicking / mouse gesturing
    on detached video
  * Videopopout position not restored
  * [PN] Less articles than expected
  * [PN] Request: add fail-safes to discover api requesting code
  * [PN] XSS in Personalized Newsreader
  * Chromium has been updated to the 54.0.2840.87 version
* Tue Oct 25 2016 sor.alexei@meowr.ru
- Update to version 41.0.2353.46:
  * No changelog available.
* Fri Oct  7 2016 kieltux@gmail.com
- Update to 40.0.2308.81:
  * Whitelist some AV software certificates
  * Backspace in URL field navigates back in history
  * Opera 39 fails to import firefox bookmarks.
  * Broken tab bar and crash on dragging a tab while it loads
  * [Settings] Checkbox aligned to top of text
  * Transparent UI items in case DWM Accent Color key missing
  * ‘Show system color on top bar’ shouldn’t be visible if
    accent color cannot be determined.
  * Remove VPN ‘Coming soon’ – WP2
* Sat Sep 24 2016 sor.alexei@meowr.ru
- Change opera.sh to reflect how and when setuid sandboxing works
  (it is not required at all when kernel supports CLONE_NEWUSER).
* Thu Sep 22 2016 kieltux@gmail.com
- Update to 40.0.2308.62:
  * Alt+drag (text selection on links) opens O-menu
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to 40.0.2308.54:
  * No changelog available.
* Wed Sep 14 2016 kieltux@gmail.com
- Update to 39.0.2256.71:
  * Deadlock when closing a bubble opened by touch
  * Provide translations for additional
    (VPN-related strings) for O39
  * Crash in opera::FreedomProxyConfigurationImpl::
    RetrieveProxyServers
  * [VPN] No temporary or permanent error when unable
    to connect to API server
  * Some requests bypass the proxy on startup (again)
  * [Linux] Hints are cut off if they fall outside the main window
  * SE-Proxy-Authorization header revealed for HTTPS
  * Whitelist some AV software certificates
  * Store custom user agent postfix in registry
* Thu Aug  4 2016 sor.alexei@meowr.ru
- Update to version 39.0.2256.48.
* Sun Jul 10 2016 kieltux@gmail.com
- Update to 38.0.2220.41:
  * Hovering bookmark below Menu crashes Opera
  * [SP] Quick clicking side panel items fails to work
  * Bold text in address bar suggestions is wrongly displayed
  * Certain pages never load completely when AdBlocker is on
  * The silent mode – fall back to Current User installation.
  * Youtube history again not being filled if ad-blocker is enabled
  * [Engine] Problems with autocomplete when typing www
  * Adblock + speedtest.net = blank page
  * YouTube shows ‘fullscreen unavailable’ message if DPI is > 100%%
* Wed Jun  8 2016 kieltux@gmail.com
- Update to 38.0.2220.29:
  * Changelog is available at
    https://opera.com/blogs/desktop/changelog-38
* Mon Jun  6 2016 kieltux@gmail.com
- Update to 37.0.2178.54:
  * Detach button won’t be visible in fullscreen anymore DNA-53205.
  * Pop out video wont freeze anymore after moving source tab
    to separate window.
  * Security fixes as chromium is updated to version 50.0.2661.102.
* Wed May  4 2016 sor.alexei@meowr.ru
- Update to version 37.0.2178.32.
- Disable IA32 build as rpmlint has a memory error with it.
* Wed Apr 13 2016 kieltux@gmail.com
- Update to 36.0.2130.65:
  * HiDPI: page scrollbar too narrow.
  * Pinch to zoom is not working.
  * Crash in
    web_modal::WebContentsModalDialogManager::ShowDialogWithManager
    with simplified printing option.
  * Download resumption not working after restart.
  * Tabs page view sticks permanently when “Adjust Speed Dial
    animations for slower hardware” is enabled.
  * Tablet mode layout and tablet mode fullscreen button not
    working.
  * Chromium is updated to version 49.0.2623.110.
* Thu Apr  7 2016 sor.alexei@meowr.ru
- Exclude libffmpeg.so* and libfreetype.so* from provides and
  requires as these are bundled and shouldn't be populated
  (boo#974251).
* Wed Mar 30 2016 kieltux@gmail.com
- Update to 36.0.2130.46:
  * [Linux] Can’t play h264 videos
  * Crash when refreshing page with mouse locked sliding toolbar
    notification
  * Go to browser settings not translated to any language
  * User-deleted speed dials with an “added” field are re-added on
    browser update without DPC version change
* Tue Mar 15 2016 kieltux@gmail.com
- Update to 36.0.2130.32:
  * Better touch support and some interface tweaks
    for Windows 10 users.
  * Hidden sync button when signed in without any problems.
  * Faster and more stable transitions between internal pages.
  * Updated support for the latest Chromium/Blink release,
    version 49.
  * Stability enhancements and bug fixes.
* Wed Mar  2 2016 kieltux@gmail.com
- Update to 35.0.2066.92:
  * Opera stops responding/freezes on various sites on
    Windows 10.
  * Monitor won’t go sleep when Opera has animated theme.
  * [Linux] Mosaic of tab bar artifacts instead of Web UIs
    when hardware accelerated.
* Mon Feb 22 2016 sor.alexei@meowr.ru
- Update to 35.0.2066.82.
* Fri Feb 19 2016 kieltux@gmail.com
- Update to 35.0.2066.68:
  * New window is not fully opened after previous was minimised.
  * Windows size ignored after AU – Opera always opens maximised.
* Mon Feb  1 2016 sor.alexei@meowr.ru
- Update to 35.0.2066.37.
- Add x86-32 build target.
* Sun Jan 24 2016 kieltux@gmail.com
- Update to 34.0.2036.50:
  * [Linux] Netflix will not play
  * Browser hangs, without crash when using Turbo
* Thu Jan 14 2016 sor.alexei@meowr.ru
- Update to 34.0.2036.47:
  * [Engine] Crash in HttpRequestHeaders::AddHeadersFromString.
  * “Mute tab” in context menu, despite flag being disabled by
    default in O34.
  * Turbo badge similar to history badge.
  * DeleteBrowserData not working need for maintenance of API.
  * Renderer crashes when trying to play a H.264 movie.
  * Issues with Montenegrin language.
  * Wrong aspect ratio on Netflix videos.
* Tue Dec  8 2015 sor.alexei@meowr.ru
- Update to 34.0.2036.25.
* Tue Nov 17 2015 baiduzhyi.devel@gmail.com
- Update to version 33.0.1990.115.
* Fri Nov 13 2015 sor.alexei@meowr.ru
- Update to 33.0.1990.58.
* Tue Oct 27 2015 sor.alexei@meowr.ru
- Update to 33.0.1990.43.
* Tue Sep 29 2015 baiduzhyi.devel@gmail.com
- Update to version 32.0.1948.69.
* Tue Sep 15 2015 sor.alexei@meowr.ru
- Update to 32.0.1948.25.
* Tue Aug 18 2015 baiduzhyi.devel@gmail.com
- Update to version 31.0.1889.174.
* Tue Aug  4 2015 baiduzhyi.devel@gmail.com
- Update to version 31.0.1889.99.
* Tue Jul 14 2015 baiduzhyi.devel@gmail.com
- Update to version 30.0.1835.125.
* Thu Jun 25 2015 baiduzhyi.devel@gmail.com
- Update to version 30.0.1835.88.
* Mon Jun 15 2015 baiduzhyi.devel@gmail.com
- Update to version 30.0.1835.59.
* Tue Jun  9 2015 sor.alexei@meowr.ru
- Update to 30.0.1835.52.
* Thu May 21 2015 sor.alexei@meowr.ru
- Update to 29.0.1795.60:
  * Update to Chromium 42.0.2311.152.
* Tue Apr 28 2015 sor.alexei@meowr.ru
- Update to 29.0.1795.47.
* Thu Apr  9 2015 sor.alexei@meowr.ru
- Update to 28.0.1750.51:
  * Chromium update to 41.0.2272.118.
  * Fix crash on initiation HiDPI.
  * HiDpi detection did not work.
* Tue Mar 10 2015 sor.alexei@meowr.ru
- Update to 28.0.1750.48.
- Remove operaprefs_fixed.ini as it's no longer possible to
  configure Opera preferences globally like that.
- Remove i586 support as upstream did.
- Don't provide browser(npapi): Opera does not support NPAPI.
- Remove opera-gtk, and opera-kde4 as Opera now uses only Aura
  which is not detachable.
- Do not enable sandboxing by default as it requires SUID to root.
- Recommend PepperFlash and ffmpeg packages as they extend
  multimedia functionality (Flash and H.264/MP3 support).
* Sun Feb  9 2014 mailaender@opensuse.org
- Update to 12.16
  * Security Fixes:
  - Replaced code signing certificate
* Sat Apr  6 2013 tittiatcoke@gmail.com
- Update to 12.15
  * Bugfixes:
  - Fixed an issue where the search bar's default engine could
    be overridden by third-party apps
  * Security Fixes:
  - Added safeguards against attacks on the RC4 encryption
    protocol
  - Fixed an issue where cookies could be set for a top-level
    domain
* Thu Feb  7 2013 tittiatcoke@gmail.com
- Update to 12.14
  * fixes crash when checking for extension updates
- Introduce full URL's to the source files.
* Fri Feb  1 2013 idonmez@suse.com
- Remove update checker application since we don't need it.
  This removes the curl dependency as a bonus.
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 12.13
  * Recommended upgrade (security and stability enhancements)
  * Genaral and User Interface
  * Fixed an issue where Opera gets internal communication errors
    on Facebook
  * Fixed an issue where no webpages load on startup, if Opera is
    disconnected from the Internet
  * Fixed an issue where images will not load after back
    navigation, when a site uses the HTML5 history API
  * Security
  * Fixed an issue where DOM events manipulation might be used to
    execute arbitrary code
  * Fixed an issue where use of SVG clipPaths could allow
    execution of arbitrary code
  * Fixed an issue where CORS requests could omit the preflight
    request
* Tue Dec 18 2012 tittiatcoke@gmail.com
- Update to 12.12
  * Fixes and Stability Enhancements
  - New option ‘Delete settings and data for all extensions’
    option (off by default) in the Delete Private Data dialog
  - Corrected an issue where using the 'Delete Private Data'
    dialog could delete extension and settings data
  - Redesigned the 'Delete Private Data' dialog to be more usable
    with small screens
  - Fixed an issue where quitting Opera while in fullscreen mode
    could cripple the interface on the next start-up
  - Fixed an issue where malformed GIF images could allow
    execution of arbitrary code
  - Fixed an issue where repeated attempts to access a target
    site could trigger address field spoofing
  - Fixed an issue where private data could be disclosed to other
    computer users, or be modified by them
* Tue Nov 20 2012 tittiatcoke@gmail.com
- Update to 12.11
  * Bug fixes
  * Stability and Security improvement
* Fri Nov 16 2012 dliang@suse.com
- Add the icon cache update to the spec file (bnc#783934)
* Tue Nov  6 2012 tittiatcoke@gmail.com
- update to 12.10
  * Improved extensions
  * Support for SPDY, CSS3 Gradients, Transitions, Animations, and Transforms
  * Support for WebSockets
  * Fullscreen and Page Visibility API
  * ICC Profiles support
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unified/1210/
* Thu Aug 30 2012 lijewski.stefan@zabka.pl
- update to 12.02
  * Fixed an issue where truncated dialogs may be used to trick users
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1202/
- fixes [bnc#778087]
* Thu Aug  2 2012 lijewski.stefan@zabka.pl
- update to 12.01
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1201/
- fixes [bnc#774191]
* Thu Jul 26 2012 lijewski.stefan@zabka.pl
- rename to README.openSUSE
* Mon Jul 16 2012 lijewski.stefan@zabka.pl
- add README-opensuse note about operapref in file
- mark operaprefs_fixed.ini as config
* Wed Jul  4 2012 lijewski.stefan@zabka.pl
- fixes [bnc#769389]:
    added global prefs file disabling opera internal
    update mechanism
- use opera provided install script
* Mon Jun 18 2012 lijewski.stefan@zabka.pl
- update to 12.00
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1200/
- fixes [bnc#767045]
* Fri May 11 2012 lijewski.stefan@zabka.pl
- update to 11.64:
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1164/
- fixes [bnc#761633]
* Thu Apr 26 2012 lijewski.stefan@zabka.pl
- update to 11.62:
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1162/
- fixes [bnc#754687], CVE-2012-1924,CVE-2012-1925,CVE-2012-1926,
  CVE-2012-1927,CVE-2012-1928,CVE-2012-1929CVE-2012-1930,
  CVE-2012-1931
* Mon Mar  5 2012 vdziewiecki@suse.com
- add Provides: browser(npapi) FATE#313084
* Sun Feb  5 2012 aj@suse.de
-  Set license to SUSE-NonFree.
* Fri Jan 27 2012 lijewski.stefan@zabka.pl
- updated to 11.61
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1161/
- fixes [bnc#743079]
* Wed Dec  7 2011 prusnak@opensuse.org
- updated to 11.60
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1160/
* Thu Oct 20 2011 prusnak@opensuse.org
- updated to 11.52
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1152/
* Sat Sep  3 2011 lijewski.stefan@gmail.com
- updated to 11.51
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1151/
* Wed Jul  6 2011 lijewski.stefan@gmail.com
- updated to 11.50
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1150/
- fixes CVE-2011-1337, CVE-2011-2609 - CVE-2011-2627 [bnc#703668]
* Wed Jul  6 2011 lijewski.stefan@gmail.com
- updated to 11.15
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1150/
- fixes [bnc#703668]
* Wed May 18 2011 prusnak@opensuse.org
- updated to 11.11
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1111/
- fixes [bnc#694567]
* Tue Apr 12 2011 prusnak@opensuse.org
- updated to 11.10
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1110/
* Thu Feb  3 2011 prusnak@opensuse.org
- updated to 11.01
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1101/
- fixes [bnc#667639], CVE-2011-0681 - CVE-2011-0687
* Thu Dec 16 2010 prusnak@opensuse.org
- updated to 11.00
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1100/
- fixes [bnc#659882]
- drop ppc build as upstream is not creating packages anymore
* Sun Oct 24 2010 prusnak@opensuse.org
- subpackages (gtk,kde4) should require main package
* Tue Oct 12 2010 prusnak@opensuse.org
- updated to 10.63
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1063/
* Tue Oct 12 2010 prusnak@opensuse.org
- updated to 10.62
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1062/
* Mon Aug 30 2010 prusnak@opensuse.org
- split off gtk and kde4 engines [bnc#635360]
* Mon Aug 23 2010 prusnak@opensuse.org
- updated to 10.61 (build 6430)
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1061/
  * fixes [bnc#630771]
* Wed Jul  7 2010 prusnak@opensuse.org
- updated to 10.60 (build 6386)
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1060/
  * fixes [bnc#583620] [bnc#607823] [bnc#615942]
* Mon Nov 23 2009 prusnak@suse.cz
- updated to 10.10 (build 4742)
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1010/
* Mon Nov  2 2009 prusnak@suse.cz
- updated to 10.01 (build 4682)
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1001/
* Tue Sep  1 2009 prusnak@suse.cz
- updated to 10.00 final (build 4585)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/opera-10-goes-final
- replaced icons with upstream ones
- hopefully closes bugs [bnc#491876], [bnc#514728], [bnc#522940]
* Tue Aug 25 2009 prusnak@suse.cz
- updated to 10.00 rc (build 4570)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/2009/08/25/opera-10-0-release-candidate
* Thu Aug 13 2009 prusnak@suse.cz
- updated to 10.00 beta 3 (build 4538)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/2009/08/13/opera-10-0-beta-3
* Mon Aug 10 2009 prusnak@suse.cz
- updated to 10.00 (build 4529)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/2009/08/07/whats-with-the-red-dots-on-the-tabs
- use Qt4 build for x86 and x86_64 (no ppc Qt4 build yet)
* Thu Aug  6 2009 prusnak@suse.cz
- updated to 10.00 (build 4520)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/2009/07/31/tab-thumbnails-on-the-sides-and-opera-unite-improvements
* Wed Jul 22 2009 prusnak@suse.cz
- updated to 10.00 (build 4502)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/2009/07/21/new-snapshot-new-possibilities
* Thu Jul 16 2009 prusnak@suse.cz
- updated to 10.00 (build 4493)
  * lots of changes - full list is available at:
    http://my.opera.com/desktopteam/blog/2009/07/16/more-than-beta-2
- added download script (download.sh, to make updates easier)
* Mon Jul 13 2009 prusnak@suse.cz
- updated to 10.00 (build 4478)
  * lots of changes - full list is available at:
    http://my.opera.com/desktopteam/blog/2009/07/09/snapshot
* Mon Jun 15 2009 prusnak@suse.cz
- updated to 10.00 (aka build 4440)
  Opera Unite
  * a collaborative technology that uses a compact server inside
    the Opera desktop browser to share data and services
  User Interface
  * "Remove From Toolbar" and other toolbar customization options
    have been moved into a submenu.
  * The ability to reset toolbar customization has been added.
  * The search field can now be resized.
  Mail, News, Chat
  * A "delete after X number of days" facility has been added.
  * Mails can now have horizontal scrollbars.
  * Fixes have been made to mail compose.
  * The adding of links to HTML mails has been improved.
  * A recovery mechanism for corrupt mail databases has been added.
  * Feed progress which sometimes stuck on non-existent resources
    has been fixed.
  * Attachments in multipart/mixedpart of multipart/alternative mail
    are now correctly displayed.
  * When viewing a message, message subjects are now a text field
    again instead of a button.
  * Additional online feed readers have been added to the feed preview
    page.
  * Sent mail is now shown when using threading in the e-mail client.
  * A thread button has been added to the message list toolbar.
  * Keyboard shortcuts for Go to Thread (D), Watch Thread (Ctrl-D),
    and Ignore Thread (Ctrl-Shift-D) have been added.
  * The encoding mismatch dialog has been removed.
  Display and scripting
  * Full RGBA support is now included.
  * Basic Web font support has been added:
    o font specification (@font-face CSS rule) with the font-family
    descriptor that controls font choices
    o src descriptor with local and remote
    o Truetype (ttf) and Scalable Vector Graphics (svg) font support
  * Support has been added for the W3C Selectors API.
  * The objects returned by getClientRects() and getBoundingClientRect()
    have been renamed to ClientRectList and ClientRect instead of
    TextRectangle and TextRectangleList.
  * XMLHttpRequests will now trigger start-loading/end-loading events.
  * The proprietary window.setDocument method has been removed.
  * Support has been added for the SVGElement.currentFps and
    SVGElement.targetFps properties to read and control SVG
    frames per second.
  * The load event for scripts is now sent after the script is executed
    rather than before.
  * The load event is now sent to frame/iframe/object elements before
    it is sent to the document.
  * A highlight will no longer be added when HTMLElement.focus()
    is called unless keyboard navigation is already activated.
  Security
  * Support for TLS 1.2 has been added.
  * SSL v2 and weak cipher support have been completely removed.
  Miscellaneous
  * Opera now supports alpha transparent widget windows on Linux
    (rounded corners).
  * The painting of windowless plugins has been fixed.
  * A Java-related issue has been fixed.
  * Fixes have been applied to font fallback problems.
  * Opera no longer recognizes or supports the http://www.w3.org/TR/REC-html40
    namespace as an alias of http://www.w3.org/1999/xhtml.
  * Core fixes, including fixes for getElementsByClassName have been made,
    which should now work with multiple classes in className.
  * Regex \b is now correctly not matching the point between
    a letter and underscore.
  * Facebook chat has been fixed.
  * Image downloading has been improved.
  * Gmail problems have been solved.
  * Files generated by the Opera installer now use the same naming scheme
    across different platforms.
  * Support for UTF-32 encoding has been removed.
  * User JS files will now be executed in alphabetical order rather than file
    system order.
  * The first ID (instead of the last) is now used on pages with duplicate IDs
    when navigating to fragment IDs.
  * Support for the altGlyph element in SVGs has been added.
  * Support for 32-bit alpha in BMP and RLE-encoded BMP images has been added.
  * Several memory leaks have been plugged.
  * Several stability issues have been fixed.
  * Network access for widgets is now opt-in:
    o All existing widgets must be updated in order to have network access.
    o All widgets on widgets.opera.com have been given Internet access.
    o Network access is specified using the network attribute of the widget element:
    + Widgets that use <widget network="private"> will have Intranet access only.
    + Widgets that use <widget network="private public"> will have Intranet and Internet access.
- replaced icons with Tango version by Tomas Kebert
* Wed Mar  4 2009 prusnak@suse.cz
- updated to 9.64 (aka build 2480)
  * Security
  * Fixed an issue where specially crafted JPEG images could be used
    to execute arbitrary code, as reported by Tavis Ormandy
    of the Google Security Team; see our advisory
  * Fixed an issue where plug-ins could be used to allow cross
    domain scripting, as reported by Adam Barth; details will
    be disclosed at a later date.
  * Fixed a moderately severe issue; details will be disclosed
    at a later date.
  * Added Untrusted Rootstore Capability:
    o Opera downloads only the detailed information about
    untrusted (blacklisted) certificates when they are encountered
    o If download fails for certificate information in the list,
    Opera considers any certificate matching the ID as untrusted
  * Added version conditional fetching of certificate dependencies
    from an online repository
  * Fixed a problem downloading the CRL (Certificate Revocation List)
  * Fixed a problem that could cause SSL to deadlock in one state,
    hanging the connection
  * Fixed a problem that could cause the incorrect calculation
    of Certificate IDs
  * Implemented Extended Validation (EV) for cross-signed EV Root
    Certificates not shipped by default
  * Implemented preshipping of the Entrust 2048 CA (Certificate Authority)
  * Implemented Root Certificate fetching from an online repository
    when an intermediate matches a certificate in the repository
  * Improved support for weak encryption when importing .p12 private
    certificates
  * Prevented security information documents from being written to disk
  * Miscellaneous
  * Fixed a problem which created separate feed notifications;
    Opera now groups them together
  * Fixed a problem with the backspace key event in the Flash plug-in
  * Fixed a problem with inline find when no text was entered,
    and the Enter key was pressed
  * Fixed an instability error with the 64 bit Linux version
* Tue Dec 16 2008 prusnak@suse.cz
- updated to 9.63 (aka build 2474)
  * Opera Presto 2.1.1 user agent engine
  * Security
  * Manipulating text input contents can allow execution of
    arbitrary code, as reported by Red XIII. See our advisory.
  * HTML parsing flaw can cause Opera to execute arbitrary code,
    as reported by Alexios Fakos. See our advisory.
  * Long hostnames in file: URLs can cause execution of arbitrary
    code, as reported by Vitaly McLain. see our advisory.
  * Script injection in feed preview can reveal contents of
    unrelated news feeds, as reported by David Bloom. See our
    advisory.
  * Built-in XSLT templates can allow cross-site scripting, as
    reported by Robert Swiecki of the Google Security Team. See our
    advisory.
  * Fixed an issue that could reveal random data, as reported
    by Matthew of Hispasec Sistemas. Details will be disclosed
    at a later date.
  * SVG images embedded using <img> tags can no longer execute
    Java or plugin content, suggested by Chris Evans.
* Wed Nov 19 2008 prusnak@suse.cz
- define default fonts for better integration into desktop
* Thu Oct 30 2008 prusnak@suse.cz
- updated to 9.62 (aka build 2466)
  o Security
  * Fixed an issue where History Search could be used to execute
    arbitrary code, as discovered by Aviv Raff; see our advisory
  * The links panel no longer allows cross-site scripting;
    see our advisory
* Tue Oct 21 2008 prusnak@suse.cz
- updated to 9.61 (aka build 2456)
  o User Interface
  * Fixed an issue with Opera Link which could generate duplicate
    bookmarks during the synchronization process
  * The image toggle button on the status bar is now a normal button,
    and does not have a menu
  o Security
  * Fixed an issue where History Search could be used to reveal
    browsing history, as reported by Roberto Suggi Liverani of
    Security-Assessment.com; see our advisory
  * Fast Forward can no longer allow cross-site scripting,
    as reported by David Bloom; see our advisory
  * Prevented news feed preview from revealing the contents of unrelated
    news feeds, as reported by David Bloom; see our advisory
* Wed Oct  8 2008 prusnak@suse.cz
- updated to 9.60 (aka build 2444)
  o User Interface
  * Opera now remembers the bookmark panel position after restart
  * Added a setting opera:config#UserPrefs|ShowBookmarksInAddressfield-
    Autocompletion to prevent bookmarks from showing in the Address
    field auto-completion drop-down
  * When setting opera:config#TransferWindow|KeepEntriesDays to 0,
    Opera now removes the transfer history when restarting
  * Sites using HTTP Auth are now saved in typed history
  * Opera now stops loading pages with iframes when closing the page
    or pressing stop
  * Page encoding in site preferences can now be reset to automatic
  * Browsing Intranet sites now works after changing proxies in
    a running session
  * Improvements to Opera Link include the synchronization of search
    engines and typed history
  * Changed the default global history to 1000
  * Added a new default speedial.ini
  * Fixed sorting by progress in Transfers
  * Fixed copying of multiple entries from the history manager
  * Fixed a bug that could cause notes to be lost when using certain
    characters
  * Fixed dataloss situation when note folders had more than one line
    in their name
  * Fixed spurious highlighting when using the space character
    in inline find
  * Fixed an issue that would prevent links in frames from being opened
    by the keyboard
  o Mail, News, Chat
  * Added popular Chinese providers in mailproviders.xml
  * Made all top-level access points (except All Messages) selectable
  * Now copes better with broken POP servers that send empty UIDLs
  * The "Large font" setting is now respected for subjects
  * Cache files from feeds no longer show up in Transfers
  * Feeds are now detected even when served as text/html
  * Fixed the synchronization of removed labels for IMAP accounts
  * Fixed an issue where the signatures wouldn't change if the default
    account signature ended with a space
  * Fixed an issue where sent message bodies could disappear under
    certain circumstances
  * Fixed DCC transfers in IRC
  o Display and Scripting
  * Improved Acid3 support: The document property has been removed from
    iframe objects for compatibility with Gecko, WebKit, and the Acid3 test
  * Added support for the caller property on functions:
    http://developer.mozilla.org/En/Core_JavaScript_1.5_Reference:Global_Objects:Function:caller
  * Special characters are now displayed properly in the Address bar
    drop-down
  * Opera Dragonfly element highlighting no longer stays on the page
    after closing the developer tools window
  * Script focused elements are no longer highlighted
  * Fixed saving of SVG when right clicking
  * Fixed an issue where custom search engines would not get a favicon
  o Security
  * Verisign and Comodo are now formally EV-enabled: see Yngve's blog post
  * Fixed an issue where specially crafted addresses could execute
    arbitrary code, as reported by Chris of Matasano Security;
    see our advisory
  * Java applets can no longer be used to read sensitive information,
    as reported by Nate McFeters; see our advisory
  o Miscellaneous
  * Added the Opera Core version (currently "Presto/2.1.1")
    to the User Agent header
  * Improved performance with large wand.dat files
  * Fixed Fast Forward on Google search results pages
  o Unix-specific changes
  * Upgrading Opera on Debian no longer resets default x-www-browser
  * Fixed an issue where text with specified size suddenly disappears
    on Qt4 builds
* Wed Aug 20 2008 lmichnovic@suse.cz
- RC2 is final: adjusted version number
  - security fixes in opera 9.52:
  * Sites can no longer change framed content on other sites
  * Fixed an issue that could allow cross-site scripting
  * Custom shortcuts no longer pass the wrong parameters to
  applications, as reported by Michael A. Puls II
  * Prevented insecure pages from showing incorrect security
  information, as reported by Lars Kleinschmidt
  * Feed links can no longer link to local files
  * Feed subscription can no longer cause the wrong page address
  to be displayed
  - other stability upgrades and features (See Changelog)
* Fri Aug 15 2008 lmichnovic@suse.cz
- update to 9.52 RC2 build 2091
  * Added Help button to "Engine Init() Failed" error message on
  start-up to inform users about problem.
  * Fixed a problem with M&T Bank.
  * Fixed a problem with POP accounts where message bodies weren't
  downloaded.
  * Fixed a small memory leak in the BitTorrent code.
  * Added bookmark path to autocompleted bookmarks in the address
  bar to better distinguish them from visited pages.
  * Disabled APOP authentication for new accounts at online.no
  (not supported by them). Users experiencing problems with
  online.no account should switch to Plaintext authentication.
  * Fixed a crash that could occur when opening mail notification
  popups on a secondary monitor.
  * Fixed a few icon/skin issues.
  * Added a "Close Tab" entry to the File menu on Windows and Linux.
  * Fixed some translation errors.
* Fri Jul  4 2008 lmichnovic@suse.cz
- update to version 9.51
  * Lot's of security and bug fixes. See Changelog for more details.
- changing filehandler.ini inside spec file, erased external source
- erased external lang files cause they are included in the tarball
* Mon Jun 16 2008 lmichnovic@suse.cz
- security update to version 9.50 [bnc#400367]
  * Lot's of security and bug fixes and new features.
  See Changelog for more details.
- all archs (i386, ppc, x86_64) use shared qt3 library and gcc4
- enabled native 64bit build [bnc#204729]
- dropped sparc arch
- Opera now works with Flash plug-in also on 64bit [bnc#336213]
- deleted bugzilla-300536-oneclick.patch because file associations
  are rewritten manually in spec file
- applying bugzilla-208048-scim-qtimm-problem.patch for all archs
- deleted unused and obsolete extra file search.ini
- using AutopreReq on
* Wed Apr 30 2008 prusnak@suse.cz
- added hicolor opera icon [bnc#384209]
  * created by Aakash Soneri (http://www.akkasone.com/)
  * redistributed with written permission of the author
  * http://akkasone.deviantart.com/art/Opera-8-Browser-Icon-22991716
- registration file opera.reg no longer needed
- refactored spec file
* Thu Apr  3 2008 lmichnovic@suse.cz
- security update to 9.27 [bnc#376714]
  * Fixed an issue where newsfeed prompts could cause Opera to
  execute arbitrary code.
  * Solved an issue where resized canvas patterns could cause Opera
  to execute arbitrary code.
  * Improved keyboard handling of password inputs.
  * Fixed a BitTorrent transfer stability issue.
  * Resolved stablity issues with the Acid 3 test.
  * Additional stability fixes.
* Thu Feb 21 2008 lmichnovic@suse.cz
- security update to 9.26 [bnc#363574]
  * Fixed an issue where simulated text inputs could trick users
  into uploading arbitrary files.
  * Image properties can no longer be used to execute scripts.
  * Fixed an issue where the representation of DOM attribute values
  could allow cross site scripting.
  * Fixed a stability issue found in Opera 9.0 to 9.25, when Opera
  connects securely to Windows Server 2008 or other servers
    supporting the TLS Certificate Status extension.
  * Additional stability fixes.
* Fri Feb 15 2008 lmichnovic@suse.cz
- owning directories /usr/share/icons/hicolor/*/*
- added missing coreutils PreReq
- set Requires: on qt3 only for build with shared libs
* Wed Jan  2 2008 lmichnovic@suse.cz
- applying oneclick patch also on ppc arch
* Wed Jan  2 2008 lmichnovic@suse.cz
- security update to 9.25 [#350579]
  CVE-2007-6520, CVE-2007-6521, CVE-2007-6522, CVE-2007-6523,
  CVE-2007-6524
  * Fixed an issue where plug-ins could be used to allow cross
  domain scripting.
  * Fixed an issue with TLS certificates that could be used to
  execute arbitrary code.
  * Rich text editing can no longer be used to allow cross domain
  scripting.
  * Fixed a problem where malformed BMP files could cause Opera to
  temporarily freeze.
  * Prevented bitmaps from revealing random data from memory.
* Mon Oct 22 2007 lmichnovic@suse.cz
- security update to 9.24
  CVE-2007-5540, CVE-2007-5541 [#334832]
  * Fixed an issue where external news readers and e-mail clients
  could be used to execute arbitrary code
  * Fixed an issue where scripts could overwrite functions on pages
  from other domains.
- updated language files to meet the version [#331913]
* Thu Oct 18 2007 ro@suse.de
- don't build on x86_64, let's use the x86 version until we
  get something native
* Fri Aug 31 2007 ltinkl@suse.cz
- fix #300536 add one-click installation associations to opera
* Thu Aug 16 2007 ltinkl@suse.cz
- update to 9.23 (#300605 - VUL-0: opera: a specially crafted
  JavaScript can make Opera execute arbitrary code)
- #300536 - add one-click installation associations to opera
* Mon Jul 23 2007 lmichnovic@suse.cz
- update to 9.22 (#293101 VUL-0: opera 9.22 fixes double free bug)
  Crafted torrent files can execute arbitrary code; CVE-2007-2809
* Tue Jul 10 2007 ltinkl@suse.cz
- fix #289701 – old opera icons
* Thu Jul  5 2007 coolo@suse.de
- put desktop file into package and replaced references to the old
  icon
* Tue May 29 2007 ltinkl@suse.cz
- update to 9.21 fix release
- fix rpmlint warning about unsupported distro (8.20)
* Mon May  7 2007 ro@suse.de
- added unzip to buildrequires
* Wed Apr 18 2007 ltinkl@suse.cz
- update to 9.20 (#264218 - VUL-0: opera version 9.20 released)
* Wed Apr  4 2007 mfabian@suse.de
- Bugzilla #208048: add workaround to start script to avoid
  bad page layout in some locales when scim-qtimm is installed.
* Tue Jan  2 2007 ltinkl@suse.cz
- update to 9.10
* Sat Sep 30 2006 ltinkl@suse.cz
- fix #189635 - opera9 cannot be installed during system upgrade
- fix #208742 - VUL-0: opera: RSA signature forgery problem
- update to 9.02
* Wed Aug 16 2006 ltinkl@suse.cz
- #190137: incompatible language files in Opera 9.0-1.1 & Opera 9.0-1.3
* Thu Aug 10 2006 ltinkl@suse.cz
- #188632 - Opera 9.0 denial of service with A tag
* Tue Jun 27 2006 ltinkl@suse.cz
- update to 9.0 final
- #187716 - VUL-0: Opera jpeg integer overflow
- #176127 - /usr/share/pixmaps/opera.xpm and /usr/share/icons/opera.xpm are directories
* Thu May  4 2006 ltinkl@suse.cz
- fix #168288 - VUL-0: opera code exec via stylesheet (update to 8.54)
* Mon Feb 20 2006 ltinkl@suse.cz
- security update to 8.52 (#151788)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 14 2005 ro@suse.de
- really use buildroot
* Tue Dec 13 2005 ltinkl@suse.cz
- add buildroot + norootforbuild
* Wed Nov 23 2005 ltinkl@suse.cz
- VUL-0: opera command line url shell command injection (#134905)
- update to 8.51
* Sat Sep 24 2005 ltinkl@suse.cz
- fix version number, really 8.50 :)
* Wed Sep 21 2005 ltinkl@suse.cz
- update to 8.05, fixing security issue #117980
* Thu Sep  1 2005 ltinkl@suse.cz
- go back to the stable version 8.02, register the version
  using the key kindly provided by Opera
* Tue Aug  2 2005 ltinkl@suse.cz
- update to 8.10 Preview
* Mon Jun 20 2005 ltinkl@suse.cz
- update to 8.01, fixing several security issues (#91179 and others)
* Mon May 23 2005 ltinkl@suse.cz
- major update to 8.0, all platforms
* Thu Feb 10 2005 ltinkl@suse.cz
- don't allow tricking the user into running arbitrary commands
  (#49218)
* Tue Oct  5 2004 ltinkl@suse.cz
- fix Netscape plugins (#46010)
* Wed Sep 15 2004 ltinkl@suse.cz
- x86 and ppc versions switched to dynamically linked against Qt (#43526)
- fix local file detection vulnerability (#43923)
- fix address bar spoofing vulnerability (#42279)
* Tue Sep 14 2004 kukuk@suse.de
- Remove OpenMotif1 and OpenMotif2 plugins [Bug #43311]
* Wed Aug 18 2004 ltinkl@suse.cz
- updated to 7.54
* Fri Jul 23 2004 ltinkl@suse.cz
- update to 7.53 (#42279)
* Fri Jul  9 2004 ltinkl@suse.cz
- update to 7.52
* Tue Jun  8 2004 ltinkl@suse.cz
- security bugfix update (#41628)
* Thu May 13 2004 ltinkl@suse.cz
- updated to 7.50 (all archs)
- threw away the now unused patch
* Mon Feb 23 2004 ltinkl@suse.cz
- updated to 7.23 for all archs
- updated the language files
- got rid of the motifwrapper hack
* Tue Sep 16 2003 aj@suse.de
- Remove broken requires.
* Thu Aug 28 2003 pthomas@suse.de
- Use the operamotifwrapper plugin from opera 7.20b as this
  is linked against the current libXm.so.3.
* Sat Aug 16 2003 adrian@suse.de
- install desktop file from kappfinder
* Fri Aug 15 2003 pthomas@suse.de
- Update ix86 and ppc to 7.11.
- Update sparc to 6.12 beta.
- Add most of the available language files.
* Wed Nov 13 2002 ro@suse.de
- comment out kde2 stuff
* Wed Aug 28 2002 uli@suse.de
- update -> 6.03 for i386 & compatibles
* Tue Aug 13 2002 ro@suse.de
- removed gnome1 support
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Thu Jul  4 2002 sndirsch@suse.de
- added german help module (Bug #16341)
* Wed Jun  5 2002 stepan@suse.de
- patch install script to recognize hammer architecture.
* Wed May 29 2002 uli@suse.de
- update -> 6.01 (secfix)
* Mon May 27 2002 uli@suse.de
- added German localization from http://www.blauwal.at/opera
  (bug #16341)
* Wed May 15 2002 uli@suse.de
- update -> 6.0 final (x86 only)
* Fri Feb 22 2002 uli@suse.de
- update -> 6.0 (x86 only)
* Wed Jan 23 2002 ro@suse.de
- build using kde2-compat
- will need port to kde3 (icon pathes only)
* Mon Sep 17 2001 uli@suse.de
- initial package, x86/sparc/ppc only
